+++
title = "Post with underscore in name"
description = "Test post to test another ox-hugo test."
date = 2017-07-20
tags = ["cross-link"]
draft = false
+++

This test post is created to test [{{< relref
"italicize-links-with-underscores" >}}]({{< relref
"italicize-links-with-underscores" >}}).
